==> zircon-1.18.165.tar.gz: zircon-1.18.165/lib/tcl81.tcl <==
#
# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/tcl81.tcl,v $
# $Date: 1998/02/09 16:57:15 $
# $Revision: 1.18.1.2 $
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
#
package provide interp 8.1
#
proc setenc {sock enc} {
    switch {} $enc return
    if {[catch {fconfigure $sock -encoding $enc} msg]} {
    }
}
#
proc sconf {sk enc} {
    global hostIPaddress
    fconfigure $sk -buffering line -translation {auto lf} -blocking 0
    setenc $sk $enc
    if {![info exists hostIPaddress]} {
	if {![catch {fconfigure $sk -sockname} xx]} {
	    set hostIPaddress [lindex $xx 0]
	}
    }
}
#
proc filecopy {f1 f2} { file copy -- $f1 $f2 }
#
proc filerename {f1 f2} { file rename -force -- $f1 $f2 }
#
proc filemkdir {f1} { file mkdir $f1 }
#
proc filedelete {f1} { file delete -- $f1 }
#
proc filedirdel {f1} { file delete -force -- $f1 }
#
proc sendSound {net nk} {
    global SoundDir zircon
    if {![info exists SoundDir($net)]} {
	if {[file exists [file join $zircon(prefdir) sounds]]} {
	    set SoundDir($net) $zircon(prefdir)/sounds
	} {
	    set SoundDir($net) [file join $zircon(lib) sounds]
	}
    }
    doSendSound $net $nk [tk_getOpenFile -defaultextension wav \
      -filetypes {{{Wav format sound files} {.\[wW\]\[aA\]\[vV\]}}} \
      -initialdir $SoundDir($net)]
}

==> zircon-1.18.173.tar.gz: zircon-1.18.173/lib/tcl81.tcl <==
#
# $Source: /home/nlfm/Zircon/lib/RCS/tcl81.tcl,v $
# $Date: 1998/08/19 12:17:43 $
# $Revision: 1.18.1.6 $
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
#
package provide interp 8.1
#
proc setenc {sock enc} {
    switch {} $enc return
    if {[catch {fconfigure $sock -encoding $enc} msg]} {
    }
}
#
proc sconf {sk enc} {
    global hostIPaddress
    fconfigure $sk -buffering line -translation {auto lf} -blocking 0
    setenc $sk $enc
    if {![info exists hostIPaddress]} {
	if {![catch {fconfigure $sk -sockname} xx]} {
	    set hostIPaddress [lindex $xx 0]
	}
    }
}
#
proc filecopy {f1 f2} { file copy -- $f1 $f2 }
#
proc filerename {f1 f2} { file rename -force -- $f1 $f2 }
#
proc filemkdir {f1} { file mkdir $f1 }
#
proc filedelete {f1} { file delete -- $f1 }
#
proc filedirdel {f1} { file delete -force -- $f1 }
#
proc sendSound {net nk} {
    global SoundDir zircon
    if {![info exists SoundDir($net)]} {
	if {[file exists [file join $zircon(prefdir) sounds]]} {
	    set SoundDir($net) [file join $zircon(prefdir) sounds]
	} {
	    set SoundDir($net) [file join $zircon(lib) sounds]
	}
    }
    set fts {}
    foreach x [$net players] {
        lappend fts [list [lindex $x 3] [lindex [lindex $x 0] 0]]
    }
    lappend fts [list {All files} {*.*}]
    doSendSound $net $nk [tk_getOpenFile -defaultextension wav \
      -filetypes $fts -initialdir $SoundDir($net)]
}
#
proc native {fl} { return [file nativename $fl] }
#
proc ncsort {lst} { return [lsort -dictionary $lst] }
